@@ -1,6 +1,6 @@
 /* gzip.h -- common declarations for all gzip modules
 
-   Copyright (C) 1997-1999, 2001, 2006-2007, 2009-2022 Free Software
+   Copyright (C) 1997-1999, 2001, 2006-2007, 2009-2023 Free Software
    Foundation, Inc.
 
    Copyright (C) 1992-1993 Jean-loup Gailly.
@@ -38,11 +38,8 @@
 #include <sys/types.h> /* for off_t */
 #include <time.h>
 #include <string.h>
-#include <stdnoreturn.h>
 #define memzero(s, n) memset ((voidp)(s), 0, (n))
 
-#define local static
-
 typedef unsigned char  uch;
 typedef unsigned short ush;
 typedef unsigned long  ulg;
@@ -254,8 +251,15 @@ extern int verbose;        /* be verbose (-v) */
 #  define Tracecv(c,x)
 #endif
 
-#define WARN(msg) {if (!quiet) fprintf msg ; \
-                   if (exit_code == OK) exit_code = WARNING;}
+#define WARN(msg) \
+  do \
+    { \
+      if (!quiet) \
+        fprintf msg; \
+      if (exit_code == OK) \
+        exit_code = WARNING; \
+    } \
+  while (false)
 
         /* in zip.c: */
 extern int zip        (int in, int out);
@@ -273,7 +277,8 @@ extern int unpack     (int in, int out);
 extern int unlzh      (int in, int out);
 
         /* in gzip.c */
-extern noreturn void abort_gzip (void);
+_Noreturn extern void finish_up_gzip (int);
+_Noreturn extern void abort_gzip (void);
 
         /* in deflate.c */
 extern off_t deflate (int pack_level);
@@ -311,11 +316,11 @@ extern char *gzip_base_name (char *fname) _GL_ATTRIBUTE_PURE;
 extern int xunlink        (char *fname);
 extern void make_simple_name (char *name);
 extern char *add_envopt   (int *argcp, char ***argvp, char const *env);
-extern noreturn void gzip_error    (char const *m);
-extern noreturn void xalloc_die    (void);
+_Noreturn extern void gzip_error (char const *m);
+_Noreturn extern void xalloc_die (void);
 extern void warning       (char const *m);
-extern noreturn void read_error    (void);
-extern noreturn void write_error   (void);
+_Noreturn extern void read_error (void);
+_Noreturn extern void write_error (void);
 extern void display_ratio (off_t num, off_t den, FILE *file);
 extern void fprint_off    (FILE *, off_t, int);
 
