@@ -12,25 +12,24 @@
 
 /* decode.c */
 
-local unsigned  decode  (unsigned count, uch buffer[]);
-local void decode_start (void);
+static unsigned  decode (unsigned count, uch buffer[]);
+static void decode_start (void);
 
 /* huf.c */
-local void huf_decode_start (void);
-local unsigned decode_c     (void);
-local unsigned decode_p     (void);
-local void read_pt_len      (int nn, int nbit, int i_special);
-local void read_c_len       (void);
+static void huf_decode_start (void);
+static unsigned decode_c (void);
+static unsigned decode_p (void);
+static void read_pt_len (int nn, int nbit, int i_special);
+static void read_c_len (void);
 
 /* io.c */
-local void fillbuf      (int n);
-local unsigned getbits  (int n);
-local void init_getbits (void);
+static void fillbuf (int n);
+static unsigned getbits (int n);
+static void init_getbits (void);
 
 /* maketbl.c */
 
-local void make_table (int nchar, uch bitlen[],
-                       int tablebits, ush table[]);
+static void make_table (int nchar, uch bitlen[], int tablebits, ush table[]);
 
 
 #define DICBIT    13    /* 12(-lh4-) or 13(-lh5-) */
@@ -67,25 +66,25 @@ local void make_table (int nchar, uch bitlen[],
 #define TBIT 5  /* smallest integer such that (1U << TBIT) > NT */
 #define NPT (1 << TBIT)
 
-/* local ush left[2 * NC - 1]; */
-/* local ush right[2 * NC - 1]; */
+/* static ush left[2 * NC - 1]; */
+/* static ush right[2 * NC - 1]; */
 #define left  prev
 #define right head
 #if NC > (1<<(BITS-2))
     error cannot overlay left+right and prev
 #endif
 
-/* local uch c_len[NC]; */
+/* static uch c_len[NC]; */
 #define c_len outbuf
 #if NC > OUTBUFSIZ
     error cannot overlay c_len and outbuf
 #endif
 
-local uch pt_len[NPT];
-local unsigned blocksize;
-local ush pt_table[256];
+static uch pt_len[NPT];
+static unsigned blocksize;
+static ush pt_table[256];
 
-/* local ush c_table[4096]; */
+/* static ush c_table[4096]; */
 #define c_table d_buf
 #if (DIST_BUFSIZE-1) < 4095
     error cannot overlay c_table and d_buf
@@ -95,12 +94,13 @@ local ush pt_table[256];
         io.c -- input/output
 ***********************************************************/
 
-local ush       bitbuf;
-local unsigned  subbitbuf;
-local int       bitcount;
+static ush       bitbuf;
+static unsigned  subbitbuf;
+static int       bitcount;
 
-local void fillbuf(n)  /* Shift bitbuf n bits left, read n bits */
-    int n;
+/* Shift bitbuf N bits left, read N bits.  */
+static void
+fillbuf (int n)
 {
     bitbuf <<= n;
     while (n > bitcount) {
@@ -112,8 +112,8 @@ local void fillbuf(n)  /* Shift bitbuf n bits left, read n bits */
     bitbuf |= subbitbuf >> (bitcount -= n);
 }
 
-local unsigned getbits(n)
-    int n;
+static unsigned
+getbits (int n)
 {
     unsigned x;
 
@@ -121,7 +121,8 @@ local unsigned getbits(n)
     return x;
 }
 
-local void init_getbits()
+static void
+init_getbits ()
 {
     bitbuf = 0;  subbitbuf = 0;  bitcount = 0;
     fillbuf(BITBUFSIZ);
@@ -131,11 +132,8 @@ local void init_getbits()
         maketbl.c -- make table for decoding
 ***********************************************************/
 
-local void make_table(nchar, bitlen, tablebits, table)
-    int nchar;
-    uch bitlen[];
-    int tablebits;
-    ush table[];
+static void
+make_table (int nchar, uch bitlen[], int tablebits, ush table[])
 {
     ush count[17], weight[17], start[18], *p;
     unsigned i, k, len, ch, jutbits, avail, nextcode, mask;
@@ -197,10 +195,8 @@ local void make_table(nchar, bitlen, tablebits, table)
         huf.c -- static Huffman
 ***********************************************************/
 
-local void read_pt_len(nn, nbit, i_special)
-    int nn;
-    int nbit;
-    int i_special;
+static void
+read_pt_len (int nn, int nbit, int i_special)
 {
     int i, c, n;
     unsigned mask;
@@ -232,7 +228,8 @@ local void read_pt_len(nn, nbit, i_special)
     }
 }
 
-local void read_c_len()
+static void
+read_c_len ()
 {
     int i, c, n;
     unsigned mask;
@@ -267,7 +264,8 @@ local void read_c_len()
     }
 }
 
-local unsigned decode_c()
+static unsigned
+decode_c ()
 {
     unsigned j, mask;
 
@@ -294,7 +292,8 @@ local unsigned decode_c()
     return j;
 }
 
-local unsigned decode_p()
+static unsigned
+decode_p ()
 {
     unsigned j, mask;
 
@@ -312,7 +311,8 @@ local unsigned decode_p()
     return j;
 }
 
-local void huf_decode_start()
+static void
+huf_decode_start ()
 {
     init_getbits();  blocksize = 0;
 }
@@ -321,10 +321,11 @@ local void huf_decode_start()
         decode.c
 ***********************************************************/
 
-local int j;    /* remaining bytes to copy */
-local int done; /* set at end of input */
+static int j;    /* remaining bytes to copy */
+static int done; /* set at end of input */
 
-local void decode_start()
+static void
+decode_start ()
 {
     huf_decode_start();
     j = 0;
@@ -333,9 +334,8 @@ local void decode_start()
 
 /* Decode the input and return the number of decoded bytes put in buffer
  */
-local unsigned decode(count, buffer)
-    unsigned count;
-    uch buffer[];
+static unsigned
+decode (unsigned count, uch buffer[])
     /* The calling function must keep the number of
        bytes to be processed.  This function decodes
        either 'count' bytes or 'DICSIZ' bytes, whichever
@@ -345,7 +345,7 @@ local unsigned decode(count, buffer)
        before calling this function.
      */
 {
-    local unsigned i;
+    static unsigned i;
     unsigned r, c;
 
     r = 0;
@@ -379,9 +379,8 @@ local unsigned decode(count, buffer)
 /* ===========================================================================
  * Unlzh in to out. Return OK or ERROR.
  */
-int unlzh(in, out)
-    int in;
-    int out;
+int
+unlzh (int in, int out)
 {
     unsigned n;
     ifd = in;
